jactorch.nn.cnn.functional
==========================

.. automodule:: jactorch.nn.cnn.functional

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      ConvBorderMode
      ConvPaddingMode
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      compute_padding_shape
      padding_nd
   
   

   
   
   








.. rubric:: Class ConvBorderMode
.. autoclass:: ConvBorderMode
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class ConvPaddingMode
.. autoclass:: ConvPaddingMode
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: compute_padding_shape

.. autofunction:: padding_nd


